import{_ as p}from"./Login.vue_vue_type_script_setup_true_lang-BwUjS0MI.js";import{e as i,f as u,v as d,p as n,ag as f,ak as m,g as l,aO as _}from"./jwt-decode.esm-CDgGQrk4.js";import{u as g}from"./workspaceStore-BT3FhueX.js";import"./OTPInput-C11pdkit.js";import"./Logo-Ck9TLZzP.js";import"./string-Chtr4fd1.js";import"./CircularLoading-ZwVXUGXl.js";import"./index-qmjWbZIE.js";import"./userStore-Bx354ZMM.js";import"./runnerData-D3DkpXdH.js";import"./url-C8wL1SIT.js";import"./colorHelpers-DssawuBS.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="0e08fa88-bf84-408b-a328-5939393fc0a4",e._sentryDebugIdIdentifier="sentry-dbid-0e08fa88-bf84-408b-a328-5939393fc0a4")}catch{}})();const b={class:"runner"},y=i({__name:"Login",setup(e){const o=f(),r=m(),a=g(),c=async()=>{const{redirect:t,...s}=r.query;if(t){await o.push({path:t,query:s,params:r.params});return}o.push({name:"playerHome",query:s})};return(t,s)=>(l(),u("div",b,[d(p,{"logo-url":n(a).state.workspace?.logoUrl??void 0,"brand-name":n(a).state.workspace?.brandName,locale:n(a).state.workspace?.language??"en",onDone:c},null,8,["logo-url","brand-name","locale"])]))}}),R=_(y,[["__scopeId","data-v-12c690e1"]]);export{R as default};
//# sourceMappingURL=Login-1_9eedC2.js.map
