import{U as a,D as r}from"./NewEditor-USya_wc4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="c8318b27-3afa-4130-ab90-2eff29aeb9ad",e._sentryDebugIdIdentifier="sentry-dbid-c8318b27-3afa-4130-ab90-2eff29aeb9ad")}catch{}})();const f=(e,n)=>a.lang.round(r.parse(e)[n]);export{f as c};
//# sourceMappingURL=channel-DJBASVFv.js.map
