import{N as c}from"./Navbar-2eN4dHoH.js";import{e as d,ak as u,b as a,l,a6 as f,f as _,g as b,v as p,k as y,aO as I}from"./jwt-decode.esm-CDgGQrk4.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-0BkRuZ6_.js";import"./constants-Ba06sOky.js";import"./PhCaretDown.vue-DTDx4WZz.js";import"./PhPencilSimple.vue-BIB1RoBS.js";import"./router-BpG4i4s5.js";import"./ts.worker-D6PTI0kj.js";import"./organization-DZwG_PV1.js";import"./tables-DSRE9aza.js";import"./string-Chtr4fd1.js";import"./keyboard-DZmqvzkN.js";import"./os-BrA46j9o.js";import"./projectStore-C0oAw13-.js";import"./project-DJKpLXkS.js";import"./organizationSwitcher-D9YqAsDM.js";import"./cascaderStore-DJXuSqPf.js";import"./folder-BnrJRrGI.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-B1sWveq6.js";import"./member-D3oa_qnJ.js";import"./index-C_mEH-cV.js";import"./index-BLA423DO.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-13LH8_ja.js";import"./PhNotePencil.vue-CMP5rg-_.js";import"./PhSignOut.vue-F6IUgKXp.js";import"./index-DStzlql6.js";import"./index-HIgToHto.js";import"./PhPlus.vue-DYrPET5X.js";import"./omniChatStore-Ci-SzxIu.js";import"./contracts.generated-BjjIIHhy.js";import"./runnerData-D3DkpXdH.js";import"./url-C8wL1SIT.js";import"./colorHelpers-DssawuBS.js";import"./uuid-DPePSF-A.js";import"./PhCopySimple.vue-DYmVlum1.js";import"./PhSparkle.vue-CIGZv6ql.js";import"./index-CDnIbPNd.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="1679ed42-3216-4c4e-af01-b3eb12c8944a",e._sentryDebugIdIdentifier="sentry-dbid-1679ed42-3216-4c4e-af01-b3eb12c8944a")}catch{}})();const v={class:"console-layout"},g={class:"console-content"},w=d({__name:"ConsoleLayout",setup(e){const o=u(),s=a(()=>!!o.params.projectId),n=a(()=>{const t=o.meta.pageNameKey;if(t)return t.startsWith("i18n_")?l.translateIfFound(t,null):t}),m=a(()=>{const t=o.params.projectId,i=o.params.tableId,r=o.params.organizationId;if(t)return{projectId:t,tableId:i,currentPageName:n.value};if(r)return{organizationId:r}});return(t,i)=>{const r=f("RouterView");return b(),_("div",v,[p(c,{"use-cascader":!0,"cascader-props":m.value,"show-ai-sparkles":s.value},null,8,["cascader-props","show-ai-sparkles"]),y("div",g,[p(r)])])}}}),io=I(w,[["__scopeId","data-v-62f8634d"]]);export{io as default};
//# sourceMappingURL=ConsoleLayout--ZCqHuqs.js.map
