import{A as n}from"./index-ByNXChjq.js";import{e as a,b as o,f as r,j as d,K as f,v as c,p as l,g as p,aO as i}from"./jwt-decode.esm-CDgGQrk4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="d0999e6e-f83b-49aa-ad99-1ba07e937a60",e._sentryDebugIdIdentifier="sentry-dbid-d0999e6e-f83b-49aa-ad99-1ba07e937a60")}catch{}})();const u=a({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,t=o(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(m,b)=>e.stepsInfo?(p(),r("nav",{key:0,class:f(["p-steps",{"full-screen":!e.isPreview}])},[c(l(n),{current:e.stepsInfo.current-1,items:t.value,responsive:!1},null,8,["current","items"])],2)):d("",!0)}}),v=i(u,[["__scopeId","data-v-58fdd395"]]);export{v as S};
//# sourceMappingURL=Steps-C2Q4YAj0.js.map
