import{C as t,_ as p}from"./View.vue_vue_type_script_setup_true_lang-7q1I9cuj.js";import{e as i,n,g as s,p as m}from"./jwt-decode.esm-CDgGQrk4.js";import{u as d}from"./projectStore-C0oAw13-.js";import"./router-BpG4i4s5.js";import"./ts.worker-D6PTI0kj.js";import"./fetch-Du9I974g.js";import"./tables-DSRE9aza.js";import"./string-Chtr4fd1.js";import"./SaveButton-Digm9PZw.js";import"./ExclamationCircleOutlined-Cl2ENDht.js";import"./CrudView-BiwpRD7A.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-E00YgeUz.js";import"./constants-Ba06sOky.js";import"./url-C8wL1SIT.js";import"./PhDotsThreeVertical.vue-Cppd2qUs.js";import"./index-DStzlql6.js";import"./asyncComputed-JQGTDnxM.js";import"./PhPencil.vue-DTja831B.js";import"./useCodebaseEvents-D0O0t0KN.js";import"./contracts.generated-BjjIIHhy.js";import"./index-qmjWbZIE.js";import"./project-DJKpLXkS.js";import"./organizationSwitcher-D9YqAsDM.js";import"./organization-DZwG_PV1.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="2e7ca566-d04c-4d04-bfb2-93f7d9fed978",o._sentryDebugIdIdentifier="sentry-dbid-2e7ca566-d04c-4d04-bfb2-93f7d9fed978")}catch{}})();const z=i({__name:"EnvVars",setup(o){const r=d(),e=new t(r.projectId);return(a,f)=>(s(),n(p,{"env-var-repository":m(e),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars-SABfpewU.js.map
