import{_ as f}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-C21R-R45.js";import{B as y}from"./BaseLayout-B8h7knHo.js";import{e as l,V as _,a3 as v,aO as u,aJ as b,aK as g,g as m,f as h,k as a,M as s,S as w,ag as S,n as k,w as n,ak as B,v as i,p as I}from"./jwt-decode.esm-CDgGQrk4.js";import{u as $}from"./editor-KY9t_hg6.js";import{A as L}from"./index-CDnIbPNd.js";import"./logo-BiWG9_W5.js";import"./Logo-Ck9TLZzP.js";import"./ts.worker-D6PTI0kj.js";import"./workspaceStore-BT3FhueX.js";import"./userStore-Bx354ZMM.js";import"./runnerData-D3DkpXdH.js";import"./url-C8wL1SIT.js";import"./colorHelpers-DssawuBS.js";import"./useCodebaseEvents-D0O0t0KN.js";import"./contracts.generated-BjjIIHhy.js";import"./linters-DgXAP-eS.js";import"./asyncComputed-JQGTDnxM.js";import"./PhBug.vue-C9dPX_2J.js";import"./router-BRdhNx8g.js";import"./constants-Ba06sOky.js";import"./index-DStzlql6.js";import"./index-HIgToHto.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="7532e881-93b8-47c0-9302-aee86065ffc0",e._sentryDebugIdIdentifier="sentry-dbid-7532e881-93b8-47c0-9302-aee86065ffc0")}catch{}})();const x=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"var(--ac-brand-primary)"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const r=_({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...v(r)}}}),D={class:"v-spinner"};function K(e,r,o,c,p,d){return b((m(),h("div",D,[a("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-even",style:s(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const P=u(x,[["render",K],["__scopeId","data-v-224007fd"]]),R={class:"content"},z=l({__name:"ProjectLogin",setup(e){const r=B(),o=S(),c=$();function p(){const t=new URL(location.href);t.searchParams.delete("api-key"),o.replace(t.pathname+t.search)}function d(){const t=r.query["api-key"];if(typeof t=="string")return t}return w(async()=>{const t=d();if(!t){o.push({name:"error"});return}await c.createLogin(t).then(p),o.push({name:"editor"})}),(t,A)=>(m(),k(y,null,{navbar:n(()=>[i(I(L),{style:{padding:"5px 25px",border:"1px solid var(--ac-border-subtle)"}},{title:n(()=>[i(f)]),_:1})]),content:n(()=>[a("div",R,[i(P)])]),_:1}))}}),oe=u(z,[["__scopeId","data-v-c9eeae4b"]]);export{oe as default};
//# sourceMappingURL=ProjectLogin-CAxwU23I.js.map
