import{e as f,ag as _,ak as p,l as s,n as m,g as c,w as b,f as g,O as y,Z as v,v as k,p as n,k as w,t as I}from"./jwt-decode.esm-CDgGQrk4.js";import{u as T}from"./projectStore-C0oAw13-.js";import{A as D,T as S}from"./index-BLA423DO.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="b15e191c-9b49-449b-bf47-69ecd5c75ff3",e._sentryDebugIdIdentifier="sentry-dbid-b15e191c-9b49-449b-bf47-69ecd5c75ff3")}catch{}})();const N=f({__name:"TablesTabs",setup(e){const a=_(),r=p(),i=String(r.name),u=T(),o=[{label:s.translate("i18n_tablestabs_tables_list"),value:"tables"},{label:s.translate("i18n_tablestabs_diagram_view"),value:"tables-diagram"},{label:s.translate("i18n_tablestabs_run_sql"),value:"sql"}],d=l=>{a.push({name:String(l),params:{projectId:u.projectId}})};return(l,h)=>(c(),m(n(S),{"active-key":n(i),options:o,"onUpdate:activeKey":d},{default:b(()=>[(c(),g(y,null,v(o,t=>k(n(D),{key:t.value,name:t.value},{tab:b(()=>[w("span",null,I(t.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{N as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang-HSUK3qRN.js.map
