const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/OidcLoginCallback-MZWTCEAU.js","assets/workspaceStore-BT3FhueX.js","assets/jwt-decode.esm-CDgGQrk4.js","assets/jwt-decode-D9gGYFRj.css","assets/userStore-Bx354ZMM.js","assets/runnerData-D3DkpXdH.js","assets/url-C8wL1SIT.js","assets/colorHelpers-DssawuBS.js","assets/OidcLogoutCallback-BGNy3a02.js","assets/Login-1_9eedC2.js","assets/Login.vue_vue_type_script_setup_true_lang-BwUjS0MI.js","assets/OTPInput-C11pdkit.js","assets/OTPInput-DkitIIgo.css","assets/Logo-Ck9TLZzP.js","assets/Logo-D2kepPyK.css","assets/string-Chtr4fd1.js","assets/CircularLoading-ZwVXUGXl.js","assets/CircularLoading-BiyobKo3.css","assets/index-qmjWbZIE.js","assets/Login-D3Bo1XNf.css","assets/Login-CobhrWJT.css","assets/Main-BlcomjUV.js","assets/PlayerNavbar-BUMHNqQd.js","assets/metadata-CI3PNpgB.js","assets/PhHouse.vue-Bf9ZQCEY.js","assets/PhMagnifyingGlass.vue-C2o1_5vv.js","assets/PhWebhooksLogo.vue-I2duYhbe.js","assets/LoadingOutlined-Cuv6kADw.js","assets/PhSignOut.vue-F6IUgKXp.js","assets/index-HIgToHto.js","assets/PlayerNavbar-DAUZYUrK.css","assets/Main-q9PQMe3g.css","assets/Home-R3DpPhb-.js","assets/Watermark-DwKsTnW2.js","assets/constants-Ba06sOky.js","assets/Watermark-Fl_4jwe9.css","assets/PageStageView-CtpOMumr.js","assets/PageStageView-Di2X0Z7S.css","assets/PhArrowSquareOut.vue-W2HSS4LB.js","assets/index-BLA423DO.js","assets/Home-letY2zGI.css","assets/Error-CD9Zm1nz.js","assets/AbstraLogo.vue_vue_type_script_setup_true_lang-C21R-R45.js","assets/logo-BiWG9_W5.js","assets/Error-CIbhyrKS.css","assets/Form-Bx0P4F7X.js","assets/FormRunner-CJcMzVTS.js","assets/Steps-C2Q4YAj0.js","assets/index-ByNXChjq.js","assets/Steps-D24tH1sk.css","assets/FormRunner-Cr_m7D0_.css","assets/redirect-QPVt7C5Z.js","assets/asyncComputed-JQGTDnxM.js","assets/uuid-DPePSF-A.js","assets/Form-B-qgu6aG.css"])))=>i.map(i=>d[i]);
import{c as u,a as d,_ as t,u as l}from"./jwt-decode.esm-CDgGQrk4.js";import{u as p}from"./userStore-Bx354ZMM.js";import{a as _}from"./workspaceStore-BT3FhueX.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="cf5accf6-aeb8-4ec9-818d-b0c15c139299",e._sentryDebugIdIdentifier="sentry-dbid-cf5accf6-aeb8-4ec9-818d-b0c15c139299")}catch{}})();const h=[{path:"/oidc-login-callback",name:"oidcLoginCallback",component:()=>t(()=>import("./OidcLoginCallback-MZWTCEAU.js"),__vite__mapDeps([0,1,2,3,4,5,6,7])),meta:{allowUnauthenticated:!0}},{path:"/oidc-logout-callback",name:"oidcLogoutCallback",component:()=>t(()=>import("./OidcLogoutCallback-BGNy3a02.js"),__vite__mapDeps([8,1,2,3,4,5,6,7])),meta:{allowUnauthenticated:!0}},{path:"/login",name:"playerLogin",component:()=>t(()=>import("./Login-1_9eedC2.js"),__vite__mapDeps([9,10,2,3,1,4,5,6,7,11,12,13,14,15,16,17,18,19,20])),meta:{allowUnauthenticated:!0}},{path:"/",name:"main",component:()=>t(()=>import("./Main-BlcomjUV.js"),__vite__mapDeps([21,22,4,2,3,1,5,6,7,23,24,25,26,27,28,29,30,31])),redirect:{name:"main"},children:[{path:"",name:"playerHome",component:()=>t(()=>import("./Home-R3DpPhb-.js"),__vite__mapDeps([32,23,24,2,3,25,26,33,1,4,5,6,7,34,35,36,16,17,37,38,39,27,40])),meta:{title:"Home"}},{path:"_player/threads",redirect:{name:"playerThreads"}},{path:"error/:status",name:"error",component:()=>t(()=>import("./Error-CD9Zm1nz.js"),__vite__mapDeps([41,42,43,13,2,3,14,34,1,4,5,6,7,39,44])),meta:{allowUnauthenticated:!0}},{path:":path(.*)*",name:"form",component:()=>t(()=>import("./Form-Bx0P4F7X.js"),__vite__mapDeps([45,4,2,3,46,10,1,5,6,7,11,12,13,14,15,16,17,18,19,47,48,49,33,34,35,50,36,37,51,52,53,54])),meta:{hideLogin:!0}}]}],i=u({history:d("/"),routes:h,scrollBehavior(e){if(e.hash)return{el:e.hash}}}),f=e=>async(a,o)=>{if(l(a,o),a.meta.allowUnauthenticated)return;const r=p();r.loadJWT();const c=await _(a.path),{redirect:s,...m}=a.query;switch(c.status){case"ALLOWED":break;case"UNAUTHORIZED":{const n=r.email;r.removeJWT(),await e.push({name:"playerLogin",query:{...m,redirect:s||a.path,reauth:n?"true":void 0,email:n||void 0},params:a.params});break}case"NOT_FOUND":await e.push({name:"error",params:{status:"404"}});break;default:await e.push({name:"error",params:{status:"403"}})}};i.beforeEach(f(i));export{h as a,f as g,i as r};
//# sourceMappingURL=router-BRdhNx8g.js.map
