import{_ as d,d as o}from"./NewEditor-USya_wc4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="d35e61a3-c442-4784-9fc7-b58263762008",e._sentryDebugIdIdentifier="sentry-dbid-d35e61a3-c442-4784-9fc7-b58263762008")}catch{}})();var b=d((e,n)=>{let t;return n==="sandbox"&&(t=o("#i"+e)),(n==="sandbox"?o(t.nodes()[0].contentDocument.body):o("body")).select(`[id="${e}"]`)},"getDiagramElement");export{b as g};
//# sourceMappingURL=chunk-55IACEB6-C2e5qS7H.js.map
