import{e as _,ag as g,r as y,S as m,f as b,g as n,n as d,w as s,v as l,p as r,T as w,q as f,t as u,B as v,l as p,E as h,bd as k,aO as x}from"./jwt-decode.esm-CDgGQrk4.js";import{u as R}from"./organizationSwitcher-D9YqAsDM.js";import"./router-BpG4i4s5.js";import"./ts.worker-D6PTI0kj.js";import"./organization-DZwG_PV1.js";import"./tables-DSRE9aza.js";import"./string-Chtr4fd1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="f7dbffc5-2744-44b1-88c2-3c87c0c9c95f",e._sentryDebugIdIdentifier="sentry-dbid-f7dbffc5-2744-44b1-88c2-3c87c0c9c95f")}catch{}})();const D={class:"loading-container"},I=_({__name:"RootRedirector",setup(e){const a=R(),c=g(),o=y(null);async function i(){o.value=null;try{const t=await a.selectDefaultOrganization();t.name==="onboarding"?window.location.href="/onboarding":c.replace(t)}catch(t){o.value=p.translate("i18n_projectsview_loading_error"),console.error("RootRedirector failed:",t)}}return m(i),(t,B)=>(n(),b("div",D,[o.value?(n(),d(r(h),{key:0,vertical:"",align:"center",gap:16},{default:s(()=>[l(r(w),{type:"danger"},{default:s(()=>[f(u(o.value),1)]),_:1}),l(r(v),{type:"primary",onClick:i},{default:s(()=>[f(u(r(p).translate("i18n_projectsview_retry")),1)]),_:1})]),_:1})):(n(),d(r(k),{key:1,size:"large"}))]))}}),N=x(I,[["__scopeId","data-v-c1eea334"]]);export{N as default};
//# sourceMappingURL=RootRedirector-CjM7Uhpj.js.map
