import{_ as n,e as u,l as f}from"./NewEditor-USya_wc4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="5ddbef09-a1b5-42f8-a095-24dc713e1732",e._sentryDebugIdIdentifier="sentry-dbid-5ddbef09-a1b5-42f8-a095-24dc713e1732")}catch{}})();var l=n((e,t,i,r)=>{e.attr("class",i);const{width:o,height:d,x:s,y:c}=w(e,t);u(e,d,o,r);const a=h(s,c,o,d,t);e.attr("viewBox",a),f.debug(`viewBox configured: ${a} with padding: ${t}`)},"setupViewPortForSVG"),w=n((e,t)=>{const i=e.node()?.getBBox()||{width:0,height:0,x:0,y:0};return{width:i.width+t*2,height:i.height+t*2,x:i.x,y:i.y}},"calculateDimensionsWithPadding"),h=n((e,t,i,r,o)=>`${e-o} ${t-o} ${i} ${r}`,"createViewBox");export{l as s};
//# sourceMappingURL=chunk-KX2RTZJC-Dvp0DWl4.js.map
