import{B as p}from"./BaseLayout-B8h7knHo.js";import{C as l}from"./ContentLayout-JqSBVSwA.js";import{e as f,ak as _,b as i,H as g,a6 as b,n as r,g as s,w as m,v as y,j as w}from"./jwt-decode.esm-CDgGQrk4.js";import{_ as v}from"./BillingAlert.vue_vue_type_script_setup_true_lang-DdwEEs18.js";import{u as z}from"./projectsStore-TBvW66-f.js";import"./router-BpG4i4s5.js";import"./ts.worker-D6PTI0kj.js";import"./index-qmjWbZIE.js";import"./member-D3oa_qnJ.js";import"./organization-DZwG_PV1.js";import"./project-DJKpLXkS.js";import"./tables-DSRE9aza.js";import"./string-Chtr4fd1.js";import"./folder-BnrJRrGI.js";import"./ant-design-1gs0Rwq1.js";import"./cascaderStore-DJXuSqPf.js";import"./organizationSwitcher-D9YqAsDM.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="6ac6c237-9987-41bc-8b18-90f128cf0110",t._sentryDebugIdIdentifier="sentry-dbid-6ac6c237-9987-41bc-8b18-90f128cf0110")}catch{}})();const $=f({__name:"Organization",setup(t){const e=_(),o=z(),n=i(()=>e.params.organizationId);g(n,a=>{a&&o.fetchedState?.organization?.id!==a&&o.fetchState(a)},{immediate:!0});const u=i(()=>o.fetchedState?.organization),c=i(()=>u.value?.billingMetadata);return(a,h)=>{const d=b("RouterView");return s(),r(p,null,{content:m(()=>[y(l,null,{default:m(()=>[c.value?(s(),r(v,{key:0,"billing-metadata":c.value,"organization-id":n.value},null,8,["billing-metadata","organization-id"])):w("",!0),(s(),r(d,{key:n.value}))]),_:1})]),_:1})}}});export{$ as default};
//# sourceMappingURL=Organization-BTpibHZK.js.map
