import{_ as t}from"./NewEditor-USya_wc4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="704bc6dc-c6fb-4923-8a23-13a7616fb871",e._sentryDebugIdIdentifier="sentry-dbid-704bc6dc-c6fb-4923-8a23-13a7616fb871")}catch{}})();function i(e,c){e.accDescr&&c.setAccDescription?.(e.accDescr),e.accTitle&&c.setAccTitle?.(e.accTitle),e.title&&c.setDiagramTitle?.(e.title)}t(i,"populateCommonDb");export{i as p};
//# sourceMappingURL=chunk-4BX2VUAB-C2qnBrZg.js.map
